<?php

$autoload = realpath(__DIR__ . '/../vendor/autoload.php');
if (!file_exists($autoload)) {
    die("Autoload file not found at path <code>$autoload</code>.");
}

require_once $autoload;

use Efi\Exception\EfiException;
use Efi\EfiPay;

// Definindo as credenciais diretamente no código
$options = [
    'clientId' => '',           
    'clientSecret' => '',  
    'certificate' => '../producao.pem',
    'sandbox' => false,
    'timeout' => 30
];

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $body = [
        "calendario" => [
            "expiracao" => 60
        ],
        "devedor" => [
            "cpf" => '07461132504',
            "nome" => 'Felipe'
        ],
        "valor" => [
            "original" => '0.04'
        ],
        "chave" => "9c8fa32c-71fc-4b41-b60a-d9379b85e02f",
        "infoAdicionais" => [
            [
                "nome" => "Produto/Serviço",
                "valor" => 'aaaaaaa'
            ]
        ]
    ];

    try {
        $api = EfiPay::getInstance($options);
        $pix = $api->pixCreateImmediateCharge([], $body);

        if (isset($pix['txid'])) {
            $params = [
                'id' => $pix['loc']['id']
            ];

            // Gera QRCode
            $qrcode = $api->pixGenerateQRCode($params);

            // Calcula a data e hora de expiração
            $expirationTimestamp = time() + $body["calendario"]["expiracao"];
            $expirationDatetime = date('d/m/Y H:i:s', $expirationTimestamp);

            // Exibe QR Code, valor, status, tempo de expiração e botão de copiar o código do Pix
            echo '<!DOCTYPE html>
            <html lang="pt-BR">
            <head>
                <meta charset="UTF-8">
                <meta name="viewport" content="width=device-width, initial-scale=1.0">
                <title>QR Code Pix</title>
                <style>
                    .container {
                        display: flex;
                        flex-direction: column;
                        align-items: center;
                        margin-top: 50px;
                    }
                    .qrcode-img {
                        margin-bottom: 20px;
                    }
                    .pix-code {
                        margin-bottom: 20px;
                        font-size: 18px;
                        word-wrap: break-word;
                        text-align: center;
                    }
                    .copy-btn {
                        padding: 10px 20px;
                        font-size: 16px;
                        cursor: pointer;
                    }
                    .pix-info {
                        margin-bottom: 20px;
                        text-align: center;
                    }
                </style>
            </head>
            <body>
                <div class="container">
                    <div class="qrcode-img">
                        <img src="' . $qrcode['imagemQrcode'] . '" alt="QR Code">
                    </div>
                    <div class="pix-info">
                        <p><strong>Valor:</strong> R$ ' . number_format($body["valor"]["original"], 2, ',', '.') . '</p>
                        <p><strong>Status:</strong> ' . ($pix['status'] ?? 'Indisponível') . '</p>
                        <p><strong>Expira em:</strong> ' . $expirationDatetime . '</p>
                    </div>
                    <div class="pix-code" id="pixCode">' . $qrcode['qrcode'] . '</div>
                    <button class="copy-btn" onclick="copyPixCode()">Copiar Código Pix</button>
                    <div id="paymentStatus"></div>
                </div>
                <script>
                    function copyPixCode() {
                        var pixCode = document.getElementById("pixCode").innerText;
                        navigator.clipboard.writeText(pixCode).then(function() {
                            alert("Código Pix copiado!");
                        }, function(err) {
                            alert("Erro ao copiar o código Pix: " + err);
                        });
                    }

                    function checkPaymentStatus() {
                        fetch("check_status.php?txid=' . $pix['txid'] . '")
                            .then(response => response.json())
                            .then(data => {
                                if (data.status === "CONCLUIDA") {
                                    document.getElementById("paymentStatus").innerHTML = "<p><strong>Pagamento aprovado!</strong></p>";
                                } else {
                                    setTimeout(checkPaymentStatus, 5000);
                                }
                            })
                            .catch(error => console.error("Erro ao verificar o status do pagamento:", error));
                    }

                    setTimeout(checkPaymentStatus, 5000);
                </script>
            </body>
            </html>';
        } else {
            echo json_encode($pix);
        }
    } catch (EfiException $e) {
        echo "EfiException Code: " . $e->code . "\n";
        echo "Error: " . $e->error . "\n";
        echo "Error Description: " . $e->errorDescription . "\n";
    } catch (Exception $e) {
        echo "Exception Message: " . $e->getMessage();
    }
}
?>

<form method="post" action="">
    <button type="submit">Gerar QR Code Pix</button>
</form>
